@@ -17,8 +17,7 @@ from typing import Dict
 import tensorflow as tf
 
 from zenml.steps.preprocesser import BasePreprocesserStep
-from zenml.steps.preprocesser.standard_preprocesser.standard_preprocesser \
-    import transformed_name
+from zenml.utils import naming_utils
 
 
 def decode_and_reshape_image(input_):
@@ -44,6 +43,6 @@ class GANPreprocessor(BasePreprocesserStep):
             if k == "image":
                 result = decode_and_reshape_image(v)
                 result = tf.cast(result, dtype=tf.float32)
-                outputs[transformed_name(k)] = result
+                outputs[naming_utils.transformed_feature_name(k)] = result
 
         return outputs
