@@ -2,13 +2,14 @@ import os
 
 from zenml.backends.processing import ProcessingDataFlowBackend
 from zenml.datasources import CSVDatasource
+from zenml.exceptions import AlreadyExistsException
 from zenml.pipelines import TrainingPipeline
 from zenml.repo import Repository, ArtifactStore
 from zenml.steps.evaluator import TFMAEvaluator
 from zenml.steps.preprocesser import StandardPreprocesser
 from zenml.steps.split import RandomSplit
 from zenml.steps.trainer import TFFeedForwardTrainer
-from zenml.exceptions import AlreadyExistsException
+from zenml.utils.naming_utils import transformed_label_name
 
 GCP_PROJECT = os.getenv('GCP_PROJECT')
 GCP_BUCKET = os.getenv('GCP_BUCKET')
@@ -41,7 +42,7 @@ training_pipeline.add_datasource(ds)
 
 # Add a split
 training_pipeline.add_split(
-    RandomSplit(split_map={'train': 0.7, 'eval': 0.3}).with_backend(
+    RandomSplit(split_map={'train': 0.7, 'eval': 0.2, 'test': 0.1}).with_backend(
         processing_backend)
 )
 
@@ -68,10 +69,10 @@ training_pipeline.add_trainer(TFFeedForwardTrainer(
 training_pipeline.add_evaluator(
     TFMAEvaluator(
         slices=[['has_diabetes']],
-        metrics={'has_diabetes': ['binary_crossentropy', 'binary_accuracy']}
+        metrics={transformed_label_name('has_diabetes'):
+                     ['binary_crossentropy', 'binary_accuracy']}
     ).with_backend(processing_backend)
 )
-
 # Define the artifact store
 artifact_store = ArtifactStore(
     os.path.join(GCP_BUCKET, 'dataflow_processing/artifact_store'))
