@@ -3,6 +3,7 @@ import os
 from zenml.backends.orchestrator import OrchestratorGCPBackend
 from zenml.backends.training import SingleGPUTrainingGCAIPBackend
 from zenml.datasources import CSVDatasource
+from zenml.exceptions import AlreadyExistsException
 from zenml.metadata import MySQLMetadataStore
 from zenml.pipelines import TrainingPipeline
 from zenml.repo import Repository, ArtifactStore
@@ -10,7 +11,7 @@ from zenml.steps.evaluator import TFMAEvaluator
 from zenml.steps.preprocesser import StandardPreprocesser
 from zenml.steps.split import RandomSplit
 from zenml.steps.trainer import TFFeedForwardTrainer
-from zenml.exceptions import AlreadyExistsException
+from zenml.utils.naming_utils import transformed_label_name
 
 GCP_PROJECT = os.getenv('GCP_PROJECT')
 GCP_BUCKET = os.getenv('GCP_BUCKET')
@@ -54,7 +55,7 @@ training_pipeline.add_datasource(ds)
 
 # Add a split
 training_pipeline.add_split(RandomSplit(
-    split_map={'train': 0.7, 'eval': 0.3}))
+    split_map={'train': 0.7, 'eval': 0.2, 'test': 0.1}))
 
 # Add a preprocessing unit
 training_pipeline.add_preprocesser(
@@ -83,8 +84,8 @@ training_pipeline.add_trainer(TFFeedForwardTrainer(
 # Add an evaluator
 training_pipeline.add_evaluator(
     TFMAEvaluator(slices=[['has_diabetes']],
-                  metrics={'has_diabetes': ['binary_crossentropy',
-                                            'binary_accuracy']}))
+                  metrics={transformed_label_name('has_diabetes'):
+                               ['binary_crossentropy', 'binary_accuracy']}))
 
 # Define the metadata store
 metadata_store = MySQLMetadataStore(
